==> custom_pages-v1.12.8.zip: custom_pages/messages/vi/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Thêm</strong> hạng mục {templateName}',
    '<strong>Custom</strong> Pages' => 'Trang <strong>Tùy chỉnh</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Sửa</strong> snippet',
    'Add' => 'Thêm',
    'Add a file icon before the title' => 'Thêm một biểu tượng file vào trước tiêu đề',
    'Adds plain HTML content to your site.' => 'Thêm plain HTML vào website của bạn',
    'Advanced' => 'Nâng cao',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Cho phép thêm trang (markdown, iframe hoặc links) vào thanh điều hướng diễn đàn',
    'Allows you to add content in MarkDown syntax.' => 'Cho phép bạn thêm nội dung bằng cú pháp ngôn ngữ MarkDown.',
    'Alternate text' => 'Văn bản thay thế',
    'Always' => 'Luôn luôn',
    'Always make a backup of your view files outside of your production environment!' => 'Luôn luôn tạo bản backup cho các file bên ngoài môi trường thực thi!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Một sự lựa chọn mẫu cho phép rỗng sẽ cho phép tất cả các mẫu chứa cho khung chứa này.',
    'Back' => 'Trở lại',
    'Back to dashboard' => 'Quay về trang chính',
    'Back to overview' => 'Quay trở lại trang Tổng quan',
    'Back to space' => 'Quay lại diễn đàn',
    'Category' => 'Nhóm link',
    'Configuration' => 'Cấu hình',
    'Content' => 'Nội dung',
    'Create' => 'Tạo mới',
    'Css Class' => 'CSS class',
    'Custom' => 'Tùy chỉnh',
    'Custom Pages' => 'Trang tùy chỉnh',
    'Custom pages' => 'Trang tùy chỉnh',
    'Dashboard' => 'Trang chính',
    'Default' => 'Mặc định',
    'Default Content' => 'Nội dung mặc định',
    'Delete' => 'Xóa',
    'Edit' => 'Chỉnh sửa',
    'Edit Page' => 'Sửa trang',
    'Empty' => 'Rỗng',
    'File' => 'File',
    'General' => 'Chung',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Icon',
    'Iframe' => 'iframe',
    'Insert' => 'Chèn',
    'Invalid request data!' => 'Dữ liệu yêu cầu không hợp lệ!',
    'Invalid template selection!' => 'Chọn mẫu không hợp lệ',
    'Invalid type selection' => 'chọn loại không hợp lệ',
    'Invalid view file selection!' => 'Chọn file xem không hợp lệ',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Điều hướng',
    'On this page you can configure general settings of your custom pages.' => 'Trên trang này bạn có thể cấu hình các thiết lập chung cho trang tùy chỉnh của bạn.',
    'Overview' => 'Tổng quan',
    'PHP' => 'PHP',
    'Pages' => 'Trang',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Lưu ý rằng các trang PHP có thể gây nguy hại tới bảo mật, đặc biệt khi xử lý dữ liệu người dùng nhập tại trang. Để hiểu rõ hơn, vui lòng tham khảo liên kết: <a href="%7Burl%7D">Yii\'s Security best practices</a>.',
    'Public' => 'Công cộng',
    'Reset' => 'Đặt lại',
    'Settings' => 'Cài đặt',
    'Show additional file information (size)' => 'Hiện thêm thông tin file (kích thước)',
    'Snippet' => 'Khối thông tin',
    'Snippets' => 'Snippets',
    'Sort Order' => 'Thứ tự sắp xếp',
    'Source' => 'Nguồn',
    'Space' => 'Diễn đàn',
    'Spaces' => 'Các diễn đàn',
    'Stream' => 'Dòng thời gian',
    'Style' => 'Style',
    'Style Class' => 'Style Class',
    'Submit' => 'Đăng',
    'Target Url' => 'Địa chỉ URL đích',
    'Template' => 'Mẫu',
    'Template Layout' => 'Template Layout',
    'Templates' => 'Mẫu',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Templates allow you to define combinable page fragments with inline edit functionality.',
    'This container does not allow any further items!' => 'This container does not allow any further items!',
    'Title' => 'Tiêu đề',
    'Top Navigation' => 'Top Navigation',
    'Topics' => 'Chủ đề',
    'Type' => 'Loại',
    'Upload image' => 'Tải lên ảnh',
    'User Account Menu (Settings)' => 'User Account Menu (Settings)',
    'Visibility' => 'Hiển thị',
    'Will embed the result of a given url as an iframe element.' => 'Will embed the result of a given url as an iframe element.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Will redirect requests to a given (relative or absolute) url.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.',
    'Without adding to navigation (Direct link)' => 'Without adding to navigation (Direct link)',
    'You are not allowed to delete default content!' => 'Bạn không được phép xóa nội dung mặc định!',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Authors' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/vi/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Thêm</strong> hạng mục {templateName}',
    '<strong>Custom</strong> Pages' => 'Trang <strong>Tùy chỉnh</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Sửa</strong> snippet',
    'Add' => 'Thêm',
    'Add a file icon before the title' => 'Thêm một biểu tượng file vào trước tiêu đề',
    'Adds plain HTML content to your site.' => 'Thêm plain HTML vào website của bạn',
    'Advanced' => 'Nâng cao',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Cho phép thêm trang (markdown, iframe hoặc links) vào thanh điều hướng diễn đàn',
    'Allows you to add content in MarkDown syntax.' => 'Cho phép bạn thêm nội dung bằng cú pháp ngôn ngữ MarkDown.',
    'Alternate text' => 'Văn bản thay thế',
    'Always' => 'Luôn luôn',
    'Always make a backup of your view files outside of your production environment!' => 'Luôn luôn tạo bản backup cho các file bên ngoài môi trường thực thi!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Một sự lựa chọn mẫu cho phép rỗng sẽ cho phép tất cả các mẫu chứa cho khung chứa này.',
    'Back' => 'Trở lại',
    'Back to dashboard' => 'Quay về trang chính',
    'Back to overview' => 'Quay trở lại trang Tổng quan',
    'Back to space' => 'Quay lại diễn đàn',
    'Category' => 'Nhóm link',
    'Configuration' => 'Cấu hình',
    'Content' => 'Nội dung',
    'Create' => 'Tạo mới',
    'Css Class' => 'CSS class',
    'Custom' => 'Tùy chỉnh',
    'Custom Pages' => 'Trang tùy chỉnh',
    'Custom pages' => 'Trang tùy chỉnh',
    'Dashboard' => 'Trang chính',
    'Default' => 'Mặc định',
    'Default Content' => 'Nội dung mặc định',
    'Delete' => 'Xóa',
    'Edit' => 'Chỉnh sửa',
    'Edit Page' => 'Sửa trang',
    'Empty' => 'Rỗng',
    'File' => 'File',
    'General' => 'Chung',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Icon',
    'Iframe' => 'iframe',
    'Insert' => 'Chèn',
    'Invalid request data!' => 'Dữ liệu yêu cầu không hợp lệ!',
    'Invalid template selection!' => 'Chọn mẫu không hợp lệ',
    'Invalid type selection' => 'chọn loại không hợp lệ',
    'Invalid view file selection!' => 'Chọn file xem không hợp lệ',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Navigation' => 'Điều hướng',
    'On this page you can configure general settings of your custom pages.' => 'Trên trang này bạn có thể cấu hình các thiết lập chung cho trang tùy chỉnh của bạn.',
    'Overview' => 'Tổng quan',
    'PHP' => 'PHP',
    'Pages' => 'Trang',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Lưu ý rằng các trang PHP có thể gây nguy hại tới bảo mật, đặc biệt khi xử lý dữ liệu người dùng nhập tại trang. Để hiểu rõ hơn, vui lòng tham khảo liên kết: <a href="%7Burl%7D">Yii\'s Security best practices</a>.',
    'Public' => 'Công cộng',
    'Reset' => 'Đặt lại',
    'Settings' => 'Cài đặt',
    'Show additional file information (size)' => 'Hiện thêm thông tin file (kích thước)',
    'Snippet' => 'Khối thông tin',
    'Snippets' => 'Snippets',
    'Sort Order' => 'Thứ tự sắp xếp',
    'Source' => 'Nguồn',
    'Space' => 'Diễn đàn',
    'Spaces' => 'Các diễn đàn',
    'Stream' => 'Dòng thời gian',
    'Style' => 'Style',
    'Style Class' => 'Style Class',
    'Submit' => 'Đăng',
    'Target Url' => 'Địa chỉ URL đích',
    'Template' => 'Mẫu',
    'Template Layout' => 'Template Layout',
    'Templates' => 'Mẫu',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'Templates allow you to define combinable page fragments with inline edit functionality.',
    'This container does not allow any further items!' => 'This container does not allow any further items!',
    'Title' => 'Tiêu đề',
    'Top Navigation' => 'Top Navigation',
    'Topics' => 'Chủ đề',
    'Type' => 'Loại',
    'Upload image' => 'Tải lên ảnh',
    'User Account Menu (Settings)' => 'User Account Menu (Settings)',
    'Visibility' => 'Hiển thị',
    'Will embed the result of a given url as an iframe element.' => 'Will embed the result of a given url as an iframe element.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Will redirect requests to a given (relative or absolute) url.',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.',
    'Without adding to navigation (Direct link)' => 'Without adding to navigation (Direct link)',
    'You are not allowed to delete default content!' => 'Bạn không được phép xóa nội dung mặc định!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Menu settings' => '',
    'Non-Logged-In Users' => '',
    'Page' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Sorting' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
